#!/usr/bin/env python
# coding: utf-8

# Copyright (c) Binh Vu.
# Distributed under the terms of the Modified BSD License.

from .slow_tunnel import SlowTunnelWidget
from ._version import __version__, version_info

from .nbextension import _jupyter_nbextension_paths
